# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn23.09

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 23.09.0
Release: 103%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

%define ovncommit 56d5cf6ccf4a7b034b3d0c009fbca7c509f2f42a

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/%{ovncommit}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit ec1d730163d984934c467e050ebf6d39f8c09384
%define ovsshortcommit ec1d730

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

BuildRequires: python3-scapy

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{ovncommit} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Tue Jan 23 2024 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-103
- controller: fixed potential segfault when changing tunnel_key and deleting ls.
[Upstream: 120075357a624293d52a1905c47a1bd249d2157c]

* Fri Jan 19 2024 Ales Musil <amusil@redhat.com> - 23.09.0-102
- northd: Use proper field for lookup_nd
[Upstream: 8e25c1c37aa3301f69bc89ee49ffaef5aa2f76fd]

* Wed Jan 17 2024 Dumitru Ceara <dceara@redhat.com> - 23.09.0-101
- checkpatch.py: Port checkpatch related changes from the OVS repo.
[Upstream: bf334c65e1ead50013880049564d445919aee61f]

* Fri Jan 12 2024 Dumitru Ceara <dceara@redhat.com> - 23.09.0-100
- actions: Make sure affinity learnt flows are auto deleted.
[Upstream: 6ce267af7124a93306d8b5bf4944379536ecd264]

* Thu Jan 11 2024 Mark Michelson <mmichels@redhat.com> - 23.09.0-99
- pinctrl: Directly retrieve desired port_binding MAC.
[Upstream: f85f5e3929c916985c7dfc0fe0f0433347d8bfae]

* Tue Jan 09 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.09.0-98
- test: add dedicated test for garp-max-timeout
[Upstream: 28fef02db946ba8113a2752e1abf61d8df5797e3]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 23.09.0-97
- treewide: Fix small memory leaks reported by static analysis
[Upstream: 0d5e6d65db19845aede9198d8e164d934a5f189e]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 23.09.0-96
- Documentation: Add note about pinning the container after release
[Upstream: 1a70f3f171c032c2329bb66f2e62d233ce19a494]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 23.09.0-95
- ci: Cover more container posibilities
[Upstream: 639aff0896527f9c48c56d6dfb3fdce84403b6dd]

* Tue Jan 09 2024 Ales Musil <amusil@redhat.com> - 23.09.0-94
- ci: Build container image before very job
[Upstream: ca0f17758559ed836dfa0220e472ea99438cefb8]

* Tue Jan 09 2024 Dumitru Ceara <dceara@redhat.com> - 23.09.0-93
- ovs: Bump submodule to include IDL "spurious delete" fix.
[Upstream: 9c97cdcd757ce356a85b3e6dde7eb19776fe4c38]

* Wed Jan 03 2024 Jacob Tanenbaum <jtanenba@redhat.com> - 23.09.0-92
- Correct ethtype referencing incorrect values
[Upstream: e9863e57320d24f8fb0d02436834f795ba58ce48]

* Mon Dec 18 2023 Numan Siddique <numans@ovn.org> - 23.09.0-91
- Revert "ovn: add geneve PMTUD support"
[Upstream: ed4e4a94ba44f5d5be5148ee82f336cab3adc7ec]

* Mon Dec 18 2023 Daniel Ding <danieldin186@gmail.com> - 23.09.0-90
- northd: forward arp request to lrp snat on.
[Upstream: 20ea3b63fb3a2fce2c9e273bfbdcb4d8399b8091]

* Wed Dec 13 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-89
- northd: fix missing port up when deleting and adding back an lsp
[Upstream: 8cabb443ae88dded5cd1800bdcea5c5760954d25]

* Fri Dec 08 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-88
- ovn-macros: Make sure stopped daemons continue before the test ends.
[Upstream: e54ec661ef67cd93d1a72de907b37fab522bc2f9]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-87
- system-test: Fix tcpdump usage in LB template tests.
[Upstream: 5141c9d4c7c861f6a65a711e59a4e64ae7d2fcdb]

* Thu Dec 07 2023 Eelco Chaudron <echaudro@redhat.com> - 23.09.0-86
- tests: Move SCTP test from kernel only to general OVN system tests.
[Upstream: 49d33629595a9c7fc44d7ac86926c83e475b322d]

* Thu Dec 07 2023 Eelco Chaudron <echaudro@redhat.com> - 23.09.0-85
- tests: Remove 'protoinfo' from the conntrack entries for SCTP tests.
[Upstream: d87ffbe44d5b5c3f143c1e38e868f9db636b4565]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-84
- northd: Skip transient IDL records.
[Upstream: 44a40011f0b7f465c1eb60c9016bd56e09d7e538]

* Thu Dec 07 2023 Ales Musil <amusil@redhat.com> - 23.09.0-83
- system-tests: Consolidate wait condition in CoPP test
[Upstream: ba7a45bde1de25868e0b16d8e58e6d523e2034ab]

* Thu Dec 07 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-82
- pinctrl: Fix up comments about sending RST packets for healthcheck.
[Upstream: 4ef375edc8bee094f24b9e649dc01ce3edd2034b]

* Mon Dec 04 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.09.0-81
- ovn: add geneve PMTUD support (#2241711)
[Upstream: e42ca82fb92cd69bbfd4da72b3c22bc57fc1ecd0]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-80
- fmt_pkt: make sure scapy-server is started once
[Upstream: b788911812171ee5d9c51806b1e287be910164c9]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-79
- fmt_pkt: improve scapy-server logging
[Upstream: 820e11754bff7b7029abf8bd8f166c169bdd8d04]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-78
- fmt_pkt: use -S check to wait for scapy sock file
[Upstream: 2d710c3b1d9444a49f80db6058462e7d33253644]

* Mon Dec 04 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-77
- fmt_pkt: don't subshell when calling ovs-appctl
[Upstream: fc311bb6d6108d49b356d9c785f6d47e7dc8faff]

* Mon Dec 04 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-76
- controller: fix group_table and meter_table allocation
[Upstream: acc63727d14ff7e9f447ed90115f74235f968499]

* Fri Dec 01 2023 Mark Michelson <mmichels@redhat.com> - 23.09.0-75
- Prepare for 23.09.2.
[Upstream: 8a000cc863773030828a4cda2167840f08c4a65c]

* Fri Dec 01 2023 Mark Michelson <mmichels@redhat.com> - 23.09.0-74
- Set release date for 23.09.1.
[Upstream: 0afd4e59e95b5f8c7b56760e91269786b0e0e52a]

* Mon Nov 27 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-73
- northd: Add missing stopwatch initialization.
[Upstream: 7fd87c5d0b1492c14d90faec4af4069496ae3609]

* Fri Nov 24 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-72
- controller: avoid extra flows if localnet_learn_fdb is disabled
[Upstream: b2f839849c36c058f940c417dc29e26165a1d30e]

* Fri Nov 24 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-71
- controller: FDB entries for localnet should not overwrite entries for vifs (#2242830)
[Upstream: 33b0117598b23b8c0877e482ee350283a147bb5f]

* Mon Nov 20 2023 Ales Musil <amusil@redhat.com> - 23.09.0-70
- controller: Disable inactivity probe for statctrl
[Upstream: bbd07439b9a8cd6db901bffcac7ac17f58e33a07]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 23.09.0-69
- pinctrl: reset success and failures n_count regardless of svc state
[Upstream: 617b84d7dd2ce3501b49e988e1ba06e86889c9bd]

* Mon Nov 20 2023 Evgenii Kovalev <ekovalev.off@gmail.com> - 23.09.0-68
- pinctrl: send RST instead of RST_ACK bit for lb hc
[Upstream: beb26027cf26271c7cd780869b540737c7916e99]

* Mon Nov 20 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-67
- controller: Don't artificially limit group and meter IDs to 16bit.
[Upstream: e9e716ad531e34766d2f02783ac08955096bf636]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-66
- tests: fixed race_condition with max_prefix
[Upstream: d257d800e41388bd2a387e0b6d5a0e41c2e8d8f1]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-65
- tests: have CHECK_NO_CHANGE_AFTER_RECOMPUTE potentially wait for ports up
[Upstream: dab54b81c7ee767943163f2aaaa27b2c4b367964]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-64
- tests: fixed "ovn-nbctl - daemon retry connection"
[Upstream: d2e0acb2a6aa510282da5e04036ec5258454c351]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-63
- tests: fixed system test "LR with SNAT fragmentation needed for external server".
[Upstream: 0bb6ba908421825428ec904d5316ae13090adbbf]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-62
- tests: fixed "interconnection - static multicast" and "- IGMP/MLD multicast"
[Upstream: 810d83e77ce3398bc94469404d85a01eb63e40bd]

* Fri Nov 17 2023 martin.kalcok@canonical.com <martin.kalcok@canonical.com> - 23.09.0-61
- ovn-ctl man: Add election timer config to manpage
[Upstream: 25d4b6855f6ce3795314e9439716f775994c7f4d]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-60
- Fix flows not removed in ha migration
[Upstream: 5375cdd96eaf8e527e5afea402f279990398710c]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-59
- binding: handle pb->chassis and pb->up from if-status module
[Upstream: 619abe5c5e18f417fe20b252ca41b70e644466e0]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-58
- binding: slight refactor if no local binding in consider_iface_release
[Upstream: d039b4332b9ea739bdf6b2efc9f5f3e422fe9a42]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-57
- controller: have I+P assigning ct_zones for l3gateway ports
[Upstream: f5d01be7f1337bdc7885dd45592aa3b376467790]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-56
- tests: fixed another set of flaky ovn-ic tests
[Upstream: 650bffdbe0562dc364faaef51f51f99e82cccc56]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-55
- tests: wait for all flows to be installed before sending packets
[Upstream: b3d03b94178bee2479d6f66ffa34255a7feb79eb]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-54
- tests: fixed "ipsec -- basic configuration"
[Upstream: ac3ece28ca04cb74b21c80e2bd73767e29cca9a3]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-53
- tests: fixed "LSP incremental processing"
[Upstream: fcbc0ae1c66e31c38ad9d5e099237e7446958035]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-52
- tests: do not start backup-northd by default
[Upstream: 54fae8cbb5db827da95a2a52ff28f29e6c7740fe]

* Fri Nov 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-51
- tests: fixed multiple tests not properly waiting for packets to be received
[Upstream: a1422144228bb9924dbc75782734a09c6ecfa534]

* Fri Nov 17 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-50
- ci: Pin Python, Fedora and Ubuntu runner versions.
[Upstream: 627955eb79c2cd374853319c1d271c2fd1aeac37]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-49
- ovs: Bump submodule to include E721 fixes.
[Upstream: 1fa7628db4155d3a39d55fe61d8d19fa7d3030af]

* Thu Nov 16 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-48
- tests: Remove broken "feature inactivity probe" test.
[Upstream: 5044376da0a1c14d1ccc4b41dfdbae14e74746b2]

* Wed Nov 15 2023 Ilya Maximets <i.maximets@ovn.org> - 23.09.0-47
- readthedocs: Add the configuration file.
[Upstream: 84c93511ce9a612b9a815cc1403b4841cc2e4c58]

* Wed Nov 15 2023 Ilya Maximets <i.maximets@ovn.org> - 23.09.0-46
- Documentation: Use theme from Read The Docs.
[Upstream: 39236dc3151baa3ace58c3ecd62ba0384b4c7a05]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-45
- ovs: Bump submodule to v3.2.1.
[Upstream: 74172ed481f7c239d9258845eb493f17d731df99]

* Wed Nov 15 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-44
- py-requirements: Remove hacking dependency and use recent flake8.
[Upstream: c6a631f066eea105c57c265dc68257d1b5ee18e4]

* Fri Nov 03 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-43
- ovn-ic: wakeup on ovsdb transaction failures
[Upstream: be4364e62ac739744c1ef5bdd74a85fe39d6e37d]

* Fri Nov 03 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-42
- ovn-ic: fix potential segmentation violation when ts is deleted
[Upstream: 5f84ff658bfd1c26bd9749c3d2e09a7e3567a8bd]

* Fri Oct 20 2023 Ales Musil <amusil@redhat.com> - 23.09.0-41
- controller, northd: Wait for cleanup before replying to exit
[Upstream: aae5b2ec8ec9f4f9f7c9738d23818c2c4967627c]

* Fri Oct 20 2023 Mark Michelson <mmichels@redhat.com> - 23.09.0-40
- tests: Add missing check for scapy.
[Upstream: ea9310a5f1e37b373abffd85f7a8dd4fefc30c4e]

* Wed Oct 18 2023 Ales Musil <amusil@redhat.com> - 23.09.0-39
- ci: Apply the ASAN workaround only for Clang <16
[Upstream: 15bf24b889b178d4cdbb6166d3bc5434ec59f9fc]

* Wed Oct 18 2023 Ales Musil <amusil@redhat.com> - 23.09.0-38
- ci: Use proper uname argument to get the HW type
[Upstream: 2efc23f3edf0293ec81a167e1c4bf99fe5601ca2]

* Thu Oct 12 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-37
- tests: Wait for new ovn-controllers to connect to Southbound.
[Upstream: 349266aac20f229b10ef0313c9f4e6b5f1af4ede]

* Wed Oct 11 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-36
- northd: Reset ls_datapath_group if not all chassis support it.
[Upstream: df7656fbf6a4ec1175b8f464a1aa6ed6e74fde29]

* Wed Oct 11 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.09.0-35
- northd: introduce ls_datapath_group column in lb sb db table
[Upstream: 276b9d47183ebd31c382742025e562fda8d14d11]

* Wed Oct 11 2023 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 23.09.0-34
- northd: sync lb applied to logical routers in sb db lb table (#2193323)
[Upstream: c33398e32b2753dd6c0cecf35ba48ad8faa69bfc]

* Tue Oct 10 2023 shylou <liuxie_11@163.com> - 23.09.0-33
- northd: Avoid snat on reply packets for dgw
[Upstream: e8c79cecef9d6e15673be1a604baaaca083f0016]

* Tue Oct 10 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-32
- northd: Incrementally process SB.Load_balancer updates.
[Upstream: a9788ef39e003b04ec426761833d85bbec1f3b84]

* Tue Oct 10 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-31
- tests: Add missing --wait=sb to the LB I-P test.
[Upstream: cadfefdf1c6457d25b6d1f93e217493739418365]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 23.09.0-30
- system-tests: Make sure that IPv6 address is available right away
[Upstream: dc9eb3a1cc95accc37165902006db6eeab25fba6]

* Tue Oct 10 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-29
- Don't mention packet cloning when failing to find tunnel
[Upstream: 44ee1a6cb40395617f5dbab5829c9f436c16a783]

* Tue Oct 10 2023 Ales Musil <amusil@redhat.com> - 23.09.0-28
- northd: Allow need frag to be SNATed
[Upstream: 94c8f952bb848806e04a857a84718d2744cfcb9f]

* Tue Oct 10 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-27
- docs: require ovn-set-local-ip for co-located ovn-controllers
[Upstream: 16bdac7965ae805040a107fc3cdade5bf4db63a2]

* Tue Oct 10 2023 Ilya Maximets <i.maximets@ovn.org> - 23.09.0-26
- memory-trim: Fix timestamp overflow warning right after reboot.
[Upstream: 32ab7d94f9258ad6e938c715380a567b4a363a62]

* Mon Oct 09 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-25
- Fix missing flows in ls_in_dhcp_options table
[Upstream: bb8fe6add97ab5fed5e4618b32c16e174faf44c8]

* Mon Oct 09 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-24
- controller: throttle port claim attempts from if-status
[Upstream: bd32a6646d21c766497494c7a1a4add05a40cd22]

* Fri Oct 06 2023 Ales Musil <amusil@redhat.com> - 23.09.0-23
- ci: Free up additional space for ovn-k jobs.
[Upstream: d30fe25c45620017ceea4f06e6e3ebd316ba734f]

* Fri Oct 06 2023 Ales Musil <amusil@redhat.com> - 23.09.0-22
- ci: Handle google-cloud-sdk -> google-cloud-cli package name change.
[Upstream: 42e81bdcebc8cd744deb8034d2fb89ec3b85bf4a]

* Fri Oct 06 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-21
- ci: Free up disk space in a more robust way.
[Upstream: cf99264e252c20edf93ab5735e18aa3225c98398]

* Fri Oct 06 2023 Dumitru Ceara <dceara@redhat.com> - 23.09.0-20
- ci: Update apt cache before installing gcc-multilib.
[Upstream: fd79876c2757f9074d38bd41cc36f59f3ba26138]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-19
- tests: fixed "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: 94b671cf89b27f54d1d03149de900994c79df415]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-18
- tests: move trim_zeros() to ovn-macros
[Upstream: 56b0435d8431518f4299c622a6ec9fc8770b8b0c]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-17
- tests: skip test "MAC binding aging" if scapy not available.
[Upstream: 148431080738bdec5e625a9ce8d470e365ee14f2]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-16
- tests: fixed "L2 Drop and Allow ACL w/ Stateful ACL"
[Upstream: 6f8719c60b8a578d564d3a6147f963fddeeacaa1]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-15
- tests: fixed multiple tests missing ovn-nbctl "wait"
[Upstream: f8cdfedacf212d9f103c2adba0c6805c01c68ff4]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-14
- tests: fixed "options:requested-chassis for logical port"
[Upstream: cd74dda22b255890a120988e8737c22a25c49957]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-13
- tests: fixed "Logical router policy packet marking"
[Upstream: e5a794dc30b087e0c78764326c86a3258f97bcc0]

* Fri Oct 06 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-12
- tests: fixed multiple ovn-ic tests
[Upstream: 0575b97dc676d8c225bc8f63befec1bf1390ebe1]

* Thu Oct 05 2023 Ales Musil <amusil@redhat.com> - 23.09.0-11
- pinctrl: Reply with correct destination for ICMPv6 RA packets
[Upstream: b93f36a248f7df3eb71b5141c5deadec7c18ee24]

* Mon Oct 02 2023 Han Zhou <hzhou@ovn.org> - 23.09.0-10
- ovn-controller: Add monitor condition for FDB.
[Upstream: c4008ae520af2561cfd68749227a8a468277e2e5]

* Thu Sep 21 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-9
- Rename scapy-server into scapy-server.py
[Upstream: d16ec6f9a063a0cb2d7bac56e23dd60d0c856b76]

* Wed Sep 20 2023 Patryk Diak <pdiak@redhat.com> - 23.09.0-8
- Add ovnkube-identity binary to the ovn-kubernetes Dockerfile
[Upstream: 35d9e42bc3e60629701743ca7e9d6890511cf0f5]

* Tue Sep 19 2023 Ihar Hrachyshka <ihrachys@redhat.com> - 23.09.0-7
- tests: offload scapy transformations to a separate unixctl daemon
[Upstream: 4a82a49363a591d429d86d60f9120166ea04cb91]

* Tue Sep 19 2023 Ales Musil <amusil@redhat.com> - 23.09.0-6
- northd: Remove hosting-chassis only if it's specified
[Upstream: 0b45a1a1cc6f081184d599ba139847ff03d90912]

* Fri Sep 15 2023 Xavier Simonart <xsimonar@redhat.com> - 23.09.0-5
- QoS: Properly set qos when ovs db is read only (#2234349)
[Upstream: 9c56ac4b74f6b964f102b94404b350417b1cd772]

* Fri Sep 15 2023 Mark Michelson <mmichels@redhat.com> - 23.09.0-4
- Prepare for 23.09.1.
[Upstream: 36f37341d32589dcd8d4bfeb023046b07dea1a44]

